% provides a particular case demonstrating that the columns
% of Q span the range of A

A = randi([-20 20],6,4);
% rank will be n = 4
fprintf('rank(A) = %d\n\n',rank(A));

% allows you to change the dimensions of m x n matrix A, m >= n
[m,n] = size(A);
[Q,R] = modqrgrsch(A);
fprintf('Basis for the range of %d x %d matrix A:\n',m,n);

% output the columns of Q
% for each of m rows
for i = 1:m
   % output the columns of row i
   for j = 1:n
      fprintf('%7.4f  ',Q(i,j));
   end
   fprintf('\n');
end
fprintf('\n');

% generate a random n x 1 vector
v = rand(n,1);
% multiply by A to get m x 1 vector v in the range of A
w = A*v;
disp('random vector w in the range of A = ');
disp(w);

% components of c are the constants such that
% c(1)*Q(:,1) + c(2)*Q(:,2) + ... + c(n)*Q(:,n) = w
%   Q*c = w
%   (Q'*Q)*c = Q'*w
%   I*c = Q'*w
%   c = Q'*w
c = Q'*w;
disp('The constants required to obtain w from the basis vectors are:');
disp(c');
disp('Apply the constants to the basis vectors to obtain w:');
disp(Q*c);
