load 'PRECGTEST';
b = ones(10000,1);
x0 = zeros(10000,1);
tol = 1.0e-6;
maxiter = 2000;

% preconditioned Cholesky with type = 'nofill'.
failure = false;
try
   start = tic;
 [x, residual, iter] = precg(PRECGTEST,b,x0,tol,maxiter);
catch icholfailure_nofill
   disp('precg failed using incomplete Cholesky with nofill.');
   failure = true;
end
if failure == false
   fprintf(['precg succeeded with nofill in %d iterations = %d\n'...
            ' with residual %.4e\n'],iter,residual);
   fprintf('Time %.3f seconds.\n',toc(start));
end

disp('---------------------------------');

droptolerance = [1.0e-2 1.0e-3 1.0e-4];

for i = 1:length(droptolerance)
   failure = false;
   try
      start = tic;
      [x, residual, iter] = precg(PRECGTEST,b,x0,tol,maxiter,...
                                  'incomplete Cholesky',droptolerance(i));
   catch icholfailure_droptol
      fprintf('precg failed with a drop tolerance = %.1e\n',...
              droptolerance(i));
      failure = true;
   end
   if failure == false
      fprintf(['precg succeeded with drop tolerance %.1e in %d iterations'...
               ' with residual %.4e\n'],droptolerance(i),iter,residual);
      fprintf('Time %.3f seconds.\n',toc(start));
   end
   disp('---------------------------------');
end

start = tic;
[x, residual, iter] = precg(PRECGTEST,b,x0,tol,maxiter,'SSOR');
fprintf(['precg succeeded using SSOR in %d iterations'...
         ' with residual %.4e\n'],iter,residual);
fprintf('Time %.3f seconds.\n',toc(start));
